==> ruler-task-0.3.8.tgz: package/lib/index.ts <==
import * as path from 'path';
import clean from './clean';
import resolve from './resolve';
import plugins from './plugins';
import * as fs from 'fs';
import * as childProcess from 'child_process';

interface Params {
  dirname: string;
  outputDir?: string;
  publicPath?: string;
  /** 是否创建路由文件 */
  createRouter?: boolean;
  /** 是否清除output的目录 */
  execClean?: boolean;
  /** 是否添加版本号 */
  addVersion?: boolean;
  /** 复制文件到指定目录 */
  copy?: {
    orginPath: string;
    targetDir: string;
    targetFileName: string;
  }[];
  /** ts-loader include */
  tsInclude?: string[];
}

interface Package {
  version: string;
}

const ExtractTextPlugin = require('extract-text-webpack-plugin');
// Node环境变量是否是development
const isDev = process.env.NODE_ENV === 'development' ? true : false;
// 默认输出目录
const defaultOutputDir = 'build';
// 默认配置参数
const defaultParams: Params = {
  dirname: '',
  outputDir: defaultOutputDir,
  publicPath: '',
  createRouter: true,
  execClean: true,
  addVersion: true,
  copy: [],
  tsInclude: []
};

export default function(params: Params): any {
  const assignParams = Object.assign({}, defaultParams, params);
  const { dirname, createRouter, execClean, addVersion, copy } = assignParams;
  const tsInclude = assignParams.tsInclude as string[];
  const outputDir = assignParams.outputDir as string;
  const publicPath = assignParams.publicPath as string;
  const pkg: Package = JSON.parse(fs.readFileSync(path.resolve(dirname, 'package.json'), { encoding: 'utf8' }));
  const filename = addVersion ? `[name]_${pkg.version}.js` : '[name].js';
  const newFs: any = fs;

  // 清空输出目录
  if (execClean) {
    clean(path.resolve(dirname, outputDir));
  }

  // 复制文件
  if (Array.isArray(copy)) {
    copy.forEach((item) => {
      let pathtemp = '';
      // 判断目标目录是否存在，不存在则一级一级的创建
      item.targetDir.split('/').forEach((dir) => {
        pathtemp = path.resolve(dirname, pathtemp, dir);
        if (!fs.existsSync(item.targetDir)) {
          fs.mkdirSync(pathtemp);
        }
      });
      newFs.copyFileSync(item.orginPath, path.join(dirname, item.targetDir, item.targetFileName));
    });
  }

  // 创建路由文件
  if (createRouter) {
    childProcess.exec('ruler transform router', { cwd: dirname });
  }

  return {
    entry: {
      index: path.resolve(dirname, './src/entry/index.tsx')
    },
    output: {
      publicPath,
      path: path.resolve(dirname, outputDir),
      filename: './js/' + filename,
      chunkFilename: 'js/' + filename
    },
    resolve: resolve(dirname),
    plugins: plugins({
      version: pkg.version,
      outputDir,
      publicPath,
      addVersion: !!addVersion
    }),
    devtool: isDev ? 'inline-source-map' : undefined,
    externals: isDev ? {
      'react/addons': true,
      'react/lib/ExecutionEnvironment': true,
      'react/lib/ReactContext': true,
      'react-addons-test-utils': 'react-dom',
    } : undefined,
    module: {
      rules: [{
        test: /.tsx?$/,
        loaders: ['ts-loader'],
        include: [
          path.resolve(dirname, 'src'),
          path.resolve(dirname, 'node_modules/ruler-component'),
          path.resolve(dirname, 'node_modules/ruler-framework'),
          path.resolve(dirname, 'node_modules/ruler-chart'),
          path.resolve(dirname, 'node_modules/ruler-utils'),
          ...tsInclude
        ]
      }, {
        test: /\.svg$/,
        loader: 'svg-sprite-loader',
        options: {
          extract: true,
          esModule: false,
          spriteFilename: `/svg/sprite_${pkg.version}.svg`
        }
      }, {
        test: /\.(png|jpg|gif)$/,
        loader: 'file-loader',
        options: {
          name: '[name].[ext]',
          outputPath: 'img/'
        }
      }, {
        test: /\.scss$/,
        use: ExtractTextPlugin.extract({
          use: [{
            loader: 'typings-for-css-modules-loader',
            options: {
              modules: true,
              namedExport: true,
              camelCase: true,
              minimize: !isDev,
              localIdentName: '[local]_[hash:base64:5]'
            }
          }, {
            loader: 'postcss-loader',
            options: {
              config: {
                path: path.resolve(__dirname, 'postcss.config.js'),
              },
              sourceMap: isDev
            }
          }, {
            loader: 'sass-loader',
            options: {
              outputStyle: 'expanded',
              sourceMap: isDev
            }
          }, {
            loader: 'sass-resources-loader',
            options: {
              resources: [
                path.resolve(dirname, 'node_modules/ruler-utils/lib/scss/mixins.scss'),
              ]
            },
          }]
        })
      }]
    }
  };
}

==> ruler-task-0.3.14.tgz: package/lib/index.ts <==
import * as path from 'path';
import clean from './clean';
import resolve from './resolve';
import plugins from './plugins';
import * as fs from 'fs';
import * as childProcess from 'child_process';

interface Params {
  dirname: string;
  outputDir?: string;
  publicPath?: string;
  /** 是否创建路由文件 */
  createRouter?: boolean;
  /** 是否清除output的目录 */
  execClean?: boolean;
  /** 是否添加版本号 */
  addVersion?: boolean;
  /** 复制文件到指定目录 */
  copy?: {
    orginPath: string;
    targetDir: string;
    targetFileName: string;
  }[];
  /** ts-loader include */
  tsInclude?: string[];
}

interface Package {
  version: string;
}

const ExtractTextPlugin = require('extract-text-webpack-plugin');
// Node环境变量是否是development
const isDev = process.env.NODE_ENV === 'development' ? true : false;
// 默认输出目录
const defaultOutputDir = 'build';
// 默认配置参数
const defaultParams: Params = {
  dirname: '',
  outputDir: defaultOutputDir,
  publicPath: '',
  createRouter: true,
  execClean: true,
  addVersion: true,
  copy: [],
  tsInclude: []
};

export default function(params: Params): any {
  const assignParams = Object.assign({}, defaultParams, params);
  const { dirname, createRouter, execClean, addVersion, copy } = assignParams;
  const tsInclude = assignParams.tsInclude as string[];
  const outputDir = assignParams.outputDir as string;
  const publicPath = assignParams.publicPath as string;
  const pkg: Package = JSON.parse(fs.readFileSync(path.resolve(dirname, 'package.json'), { encoding: 'utf8' }));
  const filename = addVersion ? `[name]_${pkg.version}.js` : '[name].js';
  const newFs: any = fs;

  // 清空输出目录
  if (execClean) {
    clean(path.resolve(dirname, outputDir));
  }

  // 复制文件
  if (Array.isArray(copy)) {
    copy.forEach((item) => {
      let pathtemp = '';
      // 判断目标目录是否存在，不存在则一级一级的创建
      item.targetDir.split('/').forEach((dir) => {
        pathtemp = path.resolve(dirname, pathtemp, dir);
        if (!fs.existsSync(item.targetDir)) {
          fs.mkdirSync(pathtemp);
        }
      });
      newFs.copyFileSync(item.orginPath, path.join(dirname, item.targetDir, item.targetFileName));
    });
  }

  // 创建路由文件
  if (createRouter) {
    childProcess.exec('ruler transform router', { cwd: dirname });
  }

  return {
    entry: {
      index: path.resolve(dirname, './src/entry/index.tsx')
    },
    output: {
      publicPath,
      path: path.resolve(dirname, outputDir),
      filename: './js/' + filename,
      chunkFilename: 'js/' + filename
    },
    resolve: resolve(dirname),
    plugins: plugins({
      version: pkg.version,
      outputDir,
      publicPath,
      dirname,
      addVersion: !!addVersion,
    }),
    devtool: isDev ? 'inline-source-map' : undefined,
    externals: isDev ? {
      'react/addons': true,
      'react/lib/ExecutionEnvironment': true,
      'react/lib/ReactContext': true,
      'react-addons-test-utils': 'react-dom',
    } : undefined,
    module: {
      rules: [{
        test: /.tsx?$/,
        loaders: ['ts-loader'],
        include: [
          path.resolve(dirname, 'src'),
          path.resolve(dirname, 'node_modules/ruler-component'),
          path.resolve(dirname, 'node_modules/ruler-framework'),
          path.resolve(dirname, 'node_modules/ruler-chart'),
          path.resolve(dirname, 'node_modules/ruler-utils'),
          ...tsInclude
        ]
      }, {
        test: /\.svg$/,
        loader: 'svg-sprite-loader',
        options: {
          extract: true,
          esModule: false,
          spriteFilename: `/svg/sprite_${pkg.version}.svg`
        }
      }, {
        test: /\.(png|jpg|gif)$/,
        loader: 'file-loader',
        options: {
          name: '[name].[ext]',
          outputPath: 'img/'
        }
      }, {
        test: /\.scss$/,
        use: ExtractTextPlugin.extract({
          use: [{
            loader: 'typings-for-css-modules-loader',
            options: {
              modules: true,
              namedExport: true,
              camelCase: true,
              minimize: !isDev,
              localIdentName: '[local]_[hash:base64:5]'
            }
          }, {
            loader: 'postcss-loader',
            options: {
              config: {
                path: path.resolve(__dirname, 'postcss.config.js'),
              },
              sourceMap: isDev
            }
          }, {
            loader: 'sass-loader',
            options: {
              outputStyle: 'expanded',
              sourceMap: isDev
            }
          }, {
            loader: 'sass-resources-loader',
            options: {
              resources: [
                path.resolve(dirname, 'node_modules/ruler-utils/lib/scss/mixins.scss'),
              ]
            },
          }]
        })
      }]
    }
  };
}
